@@ -72,7 +72,10 @@ public class Agent {
 	private ScheduledExecutorService m_scheduler = Executors.newScheduledThreadPool(10);
 	
 	/** マネージャへの疎通(Dummy)ポーリング周期（秒） */
-	private int m_managerPollingInterval = 300;
+	private int m_managerPollingInterval = 240;
+	
+	/** マネージャへの疎通ポーリングのタイムアウト(秒) */
+	private int m_managerPollingTimeout = 60;
 	
 	/** ファシリティID更新周期（秒） */
 	private long m_facilityUpdateInterval = 300;
@@ -115,6 +118,21 @@ public class Agent {
 		log.info("user.language = " + System.getProperty("user.language"));
 		log.info("file.encoding = " + System.getProperty("file.encoding"));
 		
+		// OS情報(識別したホスト名、IPアドレス)
+		log.info("nodename = " + InetAddress.getLocalHost().getHostName());
+		Enumeration networkInterfaces = NetworkInterface.getNetworkInterfaces();
+		if (null != networkInterfaces) {
+			while (networkInterfaces.hasMoreElements()) {
+				NetworkInterface ni = (NetworkInterface) networkInterfaces.nextElement();
+				Enumeration inetAddresses = ni.getInetAddresses();
+				while (inetAddresses.hasMoreElements()) {
+					InetAddress in = (InetAddress) inetAddresses.nextElement();
+					String hostAddress = in.getHostAddress();
+					log.info("ipaddress = " + hostAddress);
+				}
+			}
+		}
+		
 		// Agent設定の初期化
 		log.info("Agent.properties = " + args[0]);
 		// ログ再読み込みの機構初期化
@@ -164,6 +182,17 @@ public class Agent {
 				log.error("manager.polling.interval",e);
 			}
 		}
+		// ポーリングのタイムアウト(秒)
+		String timeout = AgentProperties.getProperty("manager.polling.timeout");
+		if (timeout != null) {
+			try {
+				m_managerPollingTimeout = Integer.parseInt(timeout);
+				log.info("manager.polling.timeout = " + m_managerPollingTimeout + " sec");
+			} catch (NumberFormatException e) {
+				log.error("manager.polling.timeout", e);
+			}
+		}
+		
 		// ファシリティ更新周期（秒）
 		interval = AgentProperties.getProperty("facility.update.interval");
 		if (interval != null) {
@@ -244,8 +273,13 @@ public class Agent {
 				m_facilityUpdateInterval,m_facilityUpdateInterval,TimeUnit.SECONDS);
 		
 		// Hinemosマネージャ間疎通タイマー開始
-		m_scheduler.scheduleWithFixedDelay(new HeartBeatTask(),
-				m_managerPollingInterval,m_managerPollingInterval,TimeUnit.SECONDS);
+		if (m_managerPollingInterval > 0) {
+			// 初回実行時刻は30秒後に固定する
+			m_scheduler.scheduleWithFixedDelay(new HeartBeatTask(this, m_managerPollingTimeout),
+					30, m_managerPollingInterval,TimeUnit.SECONDS);
+		} else {
+			log.info("hinemos heartbeat : disabled");
+		}
 		
 		// log4j再読み込みタスク
 		m_scheduler.scheduleWithFixedDelay(new ReloadLog4jTask(),
@@ -341,6 +375,11 @@ public class Agent {
 			
 		}
 
+		// 1つもfacilityIdを検出できなかった場合に警告ログを出力する
+		if(map.size() == 0){
+			log.warn("failed to detect local facilityId !");
+		}
+		
 		m_facilityIdList =map.values(); 
 
 	}
@@ -491,20 +530,42 @@ public class Agent {
 	 * 
 	 */
 	protected class HeartBeatTask implements Runnable {
-
+		
+		private Agent agent = null;
+		private int timeout = 60;
+		
 		/**
 		 * デフォルトコンストラクタ
 		 */
-		public HeartBeatTask() {
+		public HeartBeatTask(Agent agent, int timeout) {
+			this.agent = agent;
+			this.timeout = timeout;
 		}
 		
 		/**
 		 * QueueにDummyクラス送信
 		 */
 		public void run() {
+			// Queueはreconnect時に再接続しないため、動作判定に用いない
+			// (dummy msgを送信した際に、Queueも再接続される)
+			if (m_receiveTopic.isReconnecting() || m_updateRepository.isReconnecting()) {
+				log.info("skipped jms validation : now reconnecting... (job_topic = " + m_receiveTopic.isReconnecting()
+						+ ", repository_topic = " + m_updateRepository.isReconnecting() + ")");
+				return;
+			}
+			
+			Date heartbeatSendDate = null;
+			boolean sendStatus = false;
+			
 			log.debug("HeartBeatTask.run() start");
 			try{
-				sendDummy();
+				// dummy msgの送信
+				heartbeatSendDate = new Date();
+				sendStatus = sendDummy();
+				
+				// msg受信の確認
+				if (sendStatus)
+					checkMessageReceived(heartbeatSendDate);
 			}catch (Exception e) {
 				log.error("HeartBeatTask.run() catche RuntimeException", e);
 			}
@@ -515,7 +576,9 @@ public class Agent {
 		 * マネージャ側はこのDummyオブジェクトを受信した後、ログ転送エージェントへの接続確立のためTOPIC送信
 		 * 
 		 */
-		private void sendDummy(){
+		private boolean sendDummy(){
+			boolean ret = false;
+			
 			log.debug("HeartBeatTask.sendDummy() start");
 
 			if(m_facilityIdList != null && m_facilityIdList.size() > 0){
@@ -531,9 +594,43 @@ public class Agent {
 				// Dummyオブジェクトの送信
 				Dummy dummy = new Dummy(list);
 				if(m_facilityIdList.size() > 0)
-					m_sendQueue.put(dummy);
+					ret = m_sendQueue.put(dummy);
 			}
 			log.debug("HeartBeatTask.sendDummy() finish");
+			
+			return ret;
+		}
+		
+		/**
+		 * マネージャからのDummyオブジェクトの受信状況を確認する。
+		 * 受信していないと判定した場合、JMSの再接続を開始する。
+		 * 
+		 * @param sendDate Dummyオブジェクトを送信した日時
+		 */
+		private void checkMessageReceived(Date sendDate) {
+			log.debug("checking jms (hinemos heartbeat).");
+			
+			try {
+				// wait timeout (whether response is received or not)
+				Thread.sleep(timeout * 1000);
+			} catch (InterruptedException e) {
+				log.warn("skipped jms validation : wait interrupted", e);
+				return;
+			}
+			
+			if (ReceiveTopic.getHeartbeatReceiveDate().getTime() < sendDate.getTime() ||
+					UpdateRepositoryInfoReceiveTopic.getHeartbeatReceiveDate().getTime() < sendDate.getTime()) {
+				log.warn("heartbeat not received. (send : " + sendDate + ", receive(job topic) : " + ReceiveTopic.getHeartbeatReceiveDate() + ")");
+				log.warn("heartbeat not received. (send : " + sendDate + ", receive(repository topic) : " + UpdateRepositoryInfoReceiveTopic.getHeartbeatReceiveDate() + ")");
+				
+				// reconnect queue and topic
+				agent.reConnection();
+			} else {
+				if (log.isDebugEnabled()) {
+					log.debug("heartbeat received. (send : " + sendDate + ", receive(job topic) : " + ReceiveTopic.getHeartbeatReceiveDate() + ")");
+					log.debug("heartbeat received. (send : " + sendDate + ", receive(repository topic) : " + UpdateRepositoryInfoReceiveTopic.getHeartbeatReceiveDate() + ")");
+				}
+			}
 		}
 	}
 	
