@@ -351,28 +351,27 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 	/**
 	 *  
 	 */
-	synchronized private boolean reInitial() {
-
-		boolean ret = false;
-
+	private boolean reInitial() {
 		log.info("reInitial() start");
-
 		terminate();
 
-		if (initial()) {
+		boolean ret = false;
+		synchronized (this) {
+			if (initial()) {
 
-			log.info("reInitial() success!");
-			ret = true;
+				log.info("reInitial() success!");
+				ret = true;
 
-			//エラーフラグ解除
-			setErrFlg(false);
-			//履歴クリアフラグ解除
-			setClearFlg(false);
-			
-		} else {
-			log.warn("reInitial() fail!");
+				//エラーフラグ解除
+				setErrFlg(false);
+				//履歴クリアフラグ解除
+				setClearFlg(false);
+				
+			} else {
+				log.warn("reInitial() fail!");
+			}
 		}
-
+		log.info("reInitial() finish");
 		return ret;
 	}
 	/**
@@ -530,11 +529,7 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 	 * 再接続処理を行う
 	 */
 	synchronized public void reconnect() {
-		
-        setErrFlg(true);
-        
-        terminate();
-        
+		setErrFlg(true);
 	}
 	
 	/**
