@@ -73,7 +73,7 @@ public class SendQueue implements ExceptionListener {
 
 	private QueueConnectionFactory m_factory;
 
-	private volatile boolean m_isErr = false;
+	private volatile boolean m_isErr = true;
 	
 	private long m_sendQueueReconnectionInterval = 10000;
 
@@ -109,8 +109,6 @@ public class SendQueue implements ExceptionListener {
 				log.error("sendqueue.reconnection.interval",e);
 			}
 		}
-		
-		initial();
 	}
 
 	/**
@@ -352,6 +350,14 @@ public class SendQueue implements ExceptionListener {
 		m_isErr = true;
 	}
 	
+	/**
+	 * 接続状況を返す
+	 * @return 接続状況(再接続中 : true, 接続中　: false)
+	 */
+	synchronized public boolean isReconnecting() {
+		return m_isErr;
+	}
+	
 	/**
 	 * Queueメッセージ送信処理を実行するタスク用クラス
 	 */
@@ -488,4 +494,5 @@ public class SendQueue implements ExceptionListener {
 			return new Thread(r, "Reconnector-" + m_threadName);
 		}
 	}
+	
 }
