@@ -14,6 +14,7 @@
 SCRIPT_DIR=$(cd $(dirname $0);pwd)
 . ${SCRIPT_DIR}/../lib/hinemos_agent.cfg
 AGENT_LIB=${HINEMOS_AGENT_HOME}/lib
+TIMEOUT=10
 
 # change current directory
 cd ${HINEMOS_AGENT_HOME}/var/log
@@ -46,12 +47,15 @@ echo $! > ${HINEMOS_LOG_AGENT_PID}
 
 ## check process
 read PID < ${HINEMOS_LOG_AGENT_PID}
-if [ `ps --no-headers --pid ${PID} e | grep "${JAVA_HOME}/bin/java.*com.clustercontrol.logagent.Agent" | wc -l` -gt 0 ]
-then
-	echo "Hinemos Log Agent started."
-else
-	echo "Hinemos Log Agent startup failed."
-	exit 1
-fi
+for TIME in `seq 1 ${TIMEOUT}`
+do
+	if [ `ps --no-headers --pid ${PID} e | grep "${JAVA_HOME}/bin/java.*com.clustercontrol.logagent.Agent" | wc -l` -gt 0 ]
+	then
+		echo "Hinemos Log Agent started."
+		exit 0
+	fi
+	sleep 1
+done
 
-exit 0
+echo "Hinemos Log Agent startup failed."
+exit 1
